Module: Google::Cloud::SaasPlatform::SaasServiceMgmt

Defined in:
lib/google/cloud/saas_platform/saas_service_mgmt.rb,
lib/google/cloud/saas_platform/saas_service_mgmt/version.rb

Constant Summary collapse

VERSION =
"0.2.1"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.saas_platform_saas_service_mgmt| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-saas_platform-saas_service_mgmt library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



217
218
219
220
221
# File 'lib/google/cloud/saas_platform/saas_service_mgmt.rb', line 217

def self.configure
  yield ::Google::Cloud.configure.saas_platform_saas_service_mgmt if block_given?

  ::Google::Cloud.configure.saas_platform_saas_service_mgmt
end

.saas_deployments(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for SaasDeployments.

By default, this returns an instance of Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasDeployments::Client for a gRPC client for version V1beta1 of the API. However, you can specify a different API version by passing it in the version parameter. If the SaasDeployments service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SaasDeployments service. You can determine whether the method will succeed by calling saas_deployments_available?.

About SaasDeployments

Manages the deployment of SaaS services.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1beta1)

    The API version to connect to. Optional. Defaults to :v1beta1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/saas_platform/saas_service_mgmt.rb', line 76

def self.saas_deployments version: :v1beta1, transport: :grpc, &block
  require "google/cloud/saas_platform/saas_service_mgmt/#{version.to_s.downcase}"

  package_name = Google::Cloud::SaasPlatform::SaasServiceMgmt
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::SaasPlatform::SaasServiceMgmt.const_get(package_name).const_get(:SaasDeployments)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.saas_deployments_available?(version: :v1beta1, transport: :grpc) ⇒ boolean

Determines whether the SaasDeployments service is supported by the current client. If true, you can retrieve a client object by calling saas_deployments. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SaasDeployments service, or if the versioned client gem needs an update to support the SaasDeployments service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1beta1)

    The API version to connect to. Optional. Defaults to :v1beta1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/google/cloud/saas_platform/saas_service_mgmt.rb', line 100

def self.saas_deployments_available? version: :v1beta1, transport: :grpc
  require "google/cloud/saas_platform/saas_service_mgmt/#{version.to_s.downcase}"
  package_name = Google::Cloud::SaasPlatform::SaasServiceMgmt
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::SaasPlatform::SaasServiceMgmt.const_get package_name
  return false unless service_module.const_defined? :SaasDeployments
  service_module = service_module.const_get :SaasDeployments
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.saas_rollouts(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for SaasRollouts.

By default, this returns an instance of Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasRollouts::Client for a gRPC client for version V1beta1 of the API. However, you can specify a different API version by passing it in the version parameter. If the SaasRollouts service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SaasRollouts service. You can determine whether the method will succeed by calling saas_rollouts_available?.

About SaasRollouts

Manages the rollout of SaaS services.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1beta1)

    The API version to connect to. Optional. Defaults to :v1beta1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/google/cloud/saas_platform/saas_service_mgmt.rb', line 146

def self.saas_rollouts version: :v1beta1, transport: :grpc, &block
  require "google/cloud/saas_platform/saas_service_mgmt/#{version.to_s.downcase}"

  package_name = Google::Cloud::SaasPlatform::SaasServiceMgmt
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::SaasPlatform::SaasServiceMgmt.const_get(package_name).const_get(:SaasRollouts)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.saas_rollouts_available?(version: :v1beta1, transport: :grpc) ⇒ boolean

Determines whether the SaasRollouts service is supported by the current client. If true, you can retrieve a client object by calling saas_rollouts. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SaasRollouts service, or if the versioned client gem needs an update to support the SaasRollouts service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1beta1)

    The API version to connect to. Optional. Defaults to :v1beta1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/google/cloud/saas_platform/saas_service_mgmt.rb', line 170

def self.saas_rollouts_available? version: :v1beta1, transport: :grpc
  require "google/cloud/saas_platform/saas_service_mgmt/#{version.to_s.downcase}"
  package_name = Google::Cloud::SaasPlatform::SaasServiceMgmt
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::SaasPlatform::SaasServiceMgmt.const_get package_name
  return false unless service_module.const_defined? :SaasRollouts
  service_module = service_module.const_get :SaasRollouts
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end